pub unsafe extern "C" fn ejdbclose(jb: *mut EJDB) -> boolExpand description
Close a table database object. If a writer opens a database but does not close it appropriately, the database will be broken. @param jb EJDB handle. @return If successful return true, otherwise return false.