#[repr(C)]pub struct bson {
pub data: *mut c_char,
pub cur: *mut c_char,
pub dataSize: c_int,
pub finished: bson_bool_t,
pub stack: [c_int; 32],
pub stackPos: c_int,
pub err: c_int,
pub errstr: *mut c_char,
pub flags: c_int,
}Fields
data: *mut c_char< Pointer to a block of data in this BSON object.
cur: *mut c_char< Pointer to the current position.
dataSize: c_int< The number of bytes allocated to char *data.
finished: bson_bool_t< When finished, the BSON object can no longer be modified.
stack: [c_int; 32]< A stack used to keep track of nested BSON elements.
stackPos: c_int< Index of current stack position.
err: c_int< Bitfield representing errors or warnings on this buffer
errstr: *mut c_char< A string representation of the most recent error or warning.
flags: c_intTrait Implementations